@@ -174,8 +174,9 @@ func runActionImpl(step actionStep, actionDir string, remoteAction *remoteAction
 
 		logger.Debugf("type=%v actionDir=%s actionPath=%s workdir=%s actionCacheDir=%s actionName=%s containerActionDir=%s", stepModel.Type(), actionDir, actionPath, rc.Config.Workdir, rc.ActionCacheDir(), actionName, containerActionDir)
 
-		switch action.Runs.Using {
-		case model.ActionRunsUsingNode12, model.ActionRunsUsingNode16, model.ActionRunsUsingNode20:
+		x := action.Runs.Using
+		switch {
+		case x.IsNode():
 			if err := maybeCopyToActionDir(ctx, step, actionDir, actionPath, containerActionDir); err != nil {
 				return err
 			}
@@ -185,13 +186,13 @@ func runActionImpl(step actionStep, actionDir string, remoteAction *remoteAction
 			rc.ApplyExtraPath(ctx, step.getEnv())
 
 			return rc.execJobContainer(containerArgs, *step.getEnv(), "", "")(ctx)
-		case model.ActionRunsUsingDocker:
+		case x.IsDocker():
 			if remoteAction == nil {
 				actionDir = ""
 				actionPath = containerActionDir
 			}
 			return execAsDocker(ctx, step, actionName, actionDir, actionPath, remoteAction == nil, "entrypoint")
-		case model.ActionRunsUsingComposite:
+		case x.IsComposite():
 			if err := maybeCopyToActionDir(ctx, step, actionDir, actionPath, containerActionDir); err != nil {
 				return err
 			}
@@ -203,6 +204,7 @@ func runActionImpl(step actionStep, actionDir string, remoteAction *remoteAction
 				model.ActionRunsUsingNode12,
 				model.ActionRunsUsingNode16,
 				model.ActionRunsUsingNode20,
+				model.ActionRunsUsingNode24,
 				model.ActionRunsUsingComposite,
 			}, action.Runs.Using)
 		}
@@ -406,13 +408,18 @@ func newStepContainer(ctx context.Context, step step, image string, cmd []string
 
 	binds, mounts := rc.GetBindsAndMounts()
 	networkMode := fmt.Sprintf("container:%s", rc.jobContainerName())
+	var workdir string
 	if rc.IsHostEnv(ctx) {
 		networkMode = "default"
+		ext := container.LinuxContainerEnvironmentExtensions{}
+		workdir = ext.ToContainerPath(rc.Config.Workdir)
+	} else {
+		workdir = rc.JobContainer.ToContainerPath(rc.Config.Workdir)
 	}
 	stepContainer := container.NewContainer(&container.NewContainerInput{
 		Cmd:         cmd,
 		Entrypoint:  entrypoint,
-		WorkingDir:  rc.JobContainer.ToContainerPath(rc.Config.Workdir),
+		WorkingDir:  workdir,
 		Image:       image,
 		Username:    rc.Config.Secrets["DOCKER_USERNAME"],
 		Password:    rc.Config.Secrets["DOCKER_PASSWORD"],
@@ -499,12 +506,10 @@ func shouldRunPreStep(step actionStep) common.Conditional {
 func hasPreStep(step actionStep) common.Conditional {
 	return func(_ context.Context) bool {
 		action := step.getActionModel()
-		return (action.Runs.Using == model.ActionRunsUsingComposite) ||
-			((action.Runs.Using == model.ActionRunsUsingNode12 ||
-				action.Runs.Using == model.ActionRunsUsingNode16 ||
-				action.Runs.Using == model.ActionRunsUsingNode20) &&
+		return action.Runs.Using.IsComposite() ||
+			(action.Runs.Using.IsNode() &&
 				action.Runs.Pre != "") ||
-			(action.Runs.Using == model.ActionRunsUsingDocker &&
+			(action.Runs.Using.IsDocker() &&
 				action.Runs.PreEntrypoint != "")
 	}
 }
@@ -543,8 +548,9 @@ func runPreStep(step actionStep) common.Executor {
 
 		actionName, containerActionDir := getContainerActionPaths(stepModel, actionLocation, rc)
 
-		switch action.Runs.Using {
-		case model.ActionRunsUsingNode12, model.ActionRunsUsingNode16, model.ActionRunsUsingNode20:
+		x := action.Runs.Using
+		switch {
+		case x.IsNode():
 			if err := maybeCopyToActionDir(ctx, step, actionDir, actionPath, containerActionDir); err != nil {
 				return err
 			}
@@ -556,14 +562,14 @@ func runPreStep(step actionStep) common.Executor {
 
 			return rc.execJobContainer(containerArgs, *step.getEnv(), "", "")(ctx)
 
-		case model.ActionRunsUsingDocker:
+		case x.IsDocker():
 			if remoteAction == nil {
 				actionDir = ""
 				actionPath = containerActionDir
 			}
 			return execAsDocker(ctx, step, actionName, actionDir, actionPath, remoteAction == nil, "pre-entrypoint")
 
-		case model.ActionRunsUsingComposite:
+		case x.IsComposite():
 			if step.getCompositeSteps() == nil {
 				step.getCompositeRunContext(ctx)
 			}
@@ -607,12 +613,10 @@ func shouldRunPostStep(step actionStep) common.Conditional {
 func hasPostStep(step actionStep) common.Conditional {
 	return func(_ context.Context) bool {
 		action := step.getActionModel()
-		return (action.Runs.Using == model.ActionRunsUsingComposite) ||
-			((action.Runs.Using == model.ActionRunsUsingNode12 ||
-				action.Runs.Using == model.ActionRunsUsingNode16 ||
-				action.Runs.Using == model.ActionRunsUsingNode20) &&
+		return action.Runs.Using.IsComposite() ||
+			(action.Runs.Using.IsNode() &&
 				action.Runs.Post != "") ||
-			(action.Runs.Using == model.ActionRunsUsingDocker &&
+			(action.Runs.Using.IsDocker() &&
 				action.Runs.PostEntrypoint != "")
 	}
 }
@@ -648,9 +652,9 @@ func runPostStep(step actionStep) common.Executor {
 
 		actionName, containerActionDir := getContainerActionPaths(stepModel, actionLocation, rc)
 
-		switch action.Runs.Using {
-		case model.ActionRunsUsingNode12, model.ActionRunsUsingNode16, model.ActionRunsUsingNode20:
-
+		x := action.Runs.Using
+		switch {
+		case x.IsNode():
 			populateEnvsFromSavedState(step.getEnv(), step, rc)
 			populateEnvsFromInput(ctx, step.getEnv(), step.getActionModel(), rc)
 
@@ -661,14 +665,14 @@ func runPostStep(step actionStep) common.Executor {
 
 			return rc.execJobContainer(containerArgs, *step.getEnv(), "", "")(ctx)
 
-		case model.ActionRunsUsingDocker:
+		case x.IsDocker():
 			if remoteAction == nil {
 				actionDir = ""
 				actionPath = containerActionDir
 			}
 			return execAsDocker(ctx, step, actionName, actionDir, actionPath, remoteAction == nil, "post-entrypoint")
 
-		case model.ActionRunsUsingComposite:
+		case x.IsComposite():
 			if err := maybeCopyToActionDir(ctx, step, actionDir, actionPath, containerActionDir); err != nil {
 				return err
 			}
